@@ -1,9 +1,19 @@
 # flake8: noqa
 from __future__ import absolute_import
+
+import pkgutil
+
+from .constants import STRICTNESS
 from .filterset import FilterSet
 from .filters import *
 
-__version__ = '0.13.0'
+# We make the `rest_framework` module available without an additional import.
+#   If DRF is not installed, no-op.
+if pkgutil.find_loader('rest_framework') is not None:
+    from . import rest_framework
+del pkgutil
+
+__version__ = '1.1.0'
 
 
 def parse_version(version):
