@@ -1,13 +1,12 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 from collections import OrderedDict
 from datetime import timedelta
 
 from django import forms
 from django.db.models import Q
-from django.db.models.sql.constants import QUERY_TERMS
 from django.db.models.constants import LOOKUP_SEP
+from django.db.models.sql.constants import QUERY_TERMS
 from django.utils import six
 from django.utils.itercompat import is_iterable
 from django.utils.timezone import now
@@ -17,11 +16,21 @@ from .compat import pretty_name
 from .conf import settings
 from .constants import EMPTY_VALUES
 from .fields import (
-    Lookup, LookupTypeField, BaseCSVField, BaseRangeField, RangeField,
-    DateRangeField, DateTimeRangeField, TimeRangeField, IsoDateTimeField
+    BaseCSVField,
+    BaseRangeField,
+    ChoiceField,
+    DateRangeField,
+    DateTimeRangeField,
+    IsoDateTimeField,
+    Lookup,
+    LookupTypeField,
+    ModelChoiceField,
+    ModelMultipleChoiceField,
+    MultipleChoiceField,
+    RangeField,
+    TimeRangeField
 )
-from .utils import label_for_filter
-
+from .utils import deprecate, label_for_filter
 
 __all__ = [
     'AllValuesFilter',
@@ -58,23 +67,40 @@ __all__ = [
 LOOKUP_TYPES = sorted(QUERY_TERMS)
 
 
+def _extra_attr(attr):
+    fmt = ("The `.%s` attribute has been deprecated in favor of making it accessible "
+           "alongside the other field kwargs. You should now access it as `.extra['%s']`.")
+
+    def fget(self):
+        deprecate(fmt % (attr, attr))
+        return self.extra.get(attr)
+
+    def fset(self, value):
+        deprecate(fmt % (attr, attr))
+        self.extra[attr] = value
+
+    return {'fget': fget, 'fset': fset}
+
+
 class Filter(object):
     creation_counter = 0
     field_class = forms.Field
 
-    def __init__(self, name=None, label=None, widget=None, method=None, lookup_expr='exact',
-                 required=False, distinct=False, exclude=False, **kwargs):
-        self.name = name
+    def __init__(self, field_name=None, label=None, method=None, lookup_expr='exact',
+                 distinct=False, exclude=False, **kwargs):
+        self.field_name = field_name
+        if field_name is None and 'name' in kwargs:
+            deprecate("`Filter.name` has been renamed to `Filter.field_name`.")
+            self.field_name = kwargs.pop('name')
         self.label = label
         self.method = method
         self.lookup_expr = lookup_expr
-
-        self.widget = widget
-        self.required = required
-        self.extra = kwargs
         self.distinct = distinct
         self.exclude = exclude
 
+        self.extra = kwargs
+        self.extra.setdefault('required', False)
+
         self.creation_counter = Filter.creation_counter
         Filter.creation_counter += 1
 
@@ -106,12 +132,24 @@ class Filter(object):
         return locals()
     method = property(**method())
 
+    def name():
+        def fget(self):
+            deprecate("`Filter.name` has been renamed to `Filter.field_name`.")
+            return self.field_name
+
+        def fset(self, value):
+            deprecate("`Filter.name` has been renamed to `Filter.field_name`.")
+            self.field_name = value
+
+        return locals()
+    name = property(**name())
+
     def label():
         def fget(self):
             if self._label is None and hasattr(self, 'parent'):
                 model = self.parent._meta.model
                 self._label = label_for_filter(
-                    model, self.name, self.lookup_expr, self.exclude
+                    model, self.field_name, self.lookup_expr, self.exclude
                 )
             return self._label
 
@@ -121,6 +159,10 @@ class Filter(object):
         return locals()
     label = property(**label())
 
+    # deprecated field props
+    widget = property(**_extra_attr('widget'))
+    required = property(**_extra_attr('required'))
+
     @property
     def field(self):
         if not hasattr(self, '_field'):
@@ -150,13 +192,11 @@ class Filter(object):
                             if x in self.lookup_expr:
                                 lookup.append(choice)
 
-                self._field = LookupTypeField(self.field_class(
-                    required=self.required, widget=self.widget, **field_kwargs),
-                    lookup, required=self.required, label=self.label)
+                self._field = LookupTypeField(
+                    self.field_class(**field_kwargs), lookup,
+                    required=field_kwargs['required'], label=self.label)
             else:
-                self._field = self.field_class(required=self.required,
-                                               label=self.label, widget=self.widget,
-                                               **field_kwargs)
+                self._field = self.field_class(label=self.label, **field_kwargs)
         return self._field
 
     def filter(self, qs, value):
@@ -169,7 +209,7 @@ class Filter(object):
             return qs
         if self.distinct:
             qs = qs.distinct()
-        qs = self.get_method(qs)(**{'%s__%s' % (self.name, lookup): value})
+        qs = self.get_method(qs)(**{'%s__%s' % (self.field_name, lookup): value})
         return qs
 
 
@@ -182,39 +222,17 @@ class BooleanFilter(Filter):
 
 
 class ChoiceFilter(Filter):
-    field_class = forms.ChoiceField
+    field_class = ChoiceField
 
     def __init__(self, *args, **kwargs):
-        empty_label = kwargs.pop('empty_label', settings.EMPTY_CHOICE_LABEL)
-        null_label = kwargs.pop('null_label', settings.NULL_CHOICE_LABEL)
-        null_value = kwargs.pop('null_value', settings.NULL_CHOICE_VALUE)
-
-        self.null_value = null_value
-
-        if 'choices' in kwargs:
-            choices = kwargs.get('choices')
-
-            # coerce choices to list
-            if callable(choices):
-                choices = choices()
-            choices = list(choices)
-
-            # create the empty/null choices that prepend the original choices
-            prepend = []
-            if empty_label is not None:
-                prepend.append(('', empty_label))
-            if null_label is not None:
-                prepend.append((null_value, null_label))
-
-            kwargs['choices'] = prepend + choices
-
+        self.null_value = kwargs.get('null_value', settings.NULL_CHOICE_VALUE)
         super(ChoiceFilter, self).__init__(*args, **kwargs)
 
     def filter(self, qs, value):
         if value != self.null_value:
             return super(ChoiceFilter, self).filter(qs, value)
 
-        qs = self.get_method(qs)(**{'%s__%s' % (self.name, self.lookup_expr): None})
+        qs = self.get_method(qs)(**{'%s__%s' % (self.field_name, self.lookup_expr): None})
         return qs.distinct() if self.distinct else qs
 
 
@@ -249,13 +267,14 @@ class MultipleChoiceFilter(Filter):
     `distinct` defaults to `True` as to-many relationships will generally
     require this.
     """
-    field_class = forms.MultipleChoiceField
+    field_class = MultipleChoiceField
 
     always_filter = True
 
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('distinct', True)
         self.conjoined = kwargs.pop('conjoined', False)
+        self.null_value = kwargs.get('null_value', settings.NULL_CHOICE_VALUE)
         super(MultipleChoiceFilter, self).__init__(*args, **kwargs)
 
     def is_noop(self, qs, value):
@@ -267,7 +286,7 @@ class MultipleChoiceFilter(Filter):
             return False
 
         # A reasonable default for being a noop...
-        if self.required and len(value) == len(self.field.choices):
+        if self.extra.get('required') and len(value) == len(self.field.choices):
             return True
 
         return False
@@ -283,6 +302,8 @@ class MultipleChoiceFilter(Filter):
         if not self.conjoined:
             q = Q()
         for v in set(value):
+            if v == self.null_value:
+                v = None
             predicate = self.get_filter_predicate(v)
             if self.conjoined:
                 qs = self.get_method(qs)(**predicate)
@@ -296,9 +317,9 @@ class MultipleChoiceFilter(Filter):
 
     def get_filter_predicate(self, v):
         try:
-            return {self.name: getattr(v, self.field.to_field_name)}
+            return {self.field_name: getattr(v, self.field.to_field_name)}
         except (AttributeError, TypeError):
-            return {self.name: v}
+            return {self.field_name: v}
 
 
 class TypedMultipleChoiceFilter(MultipleChoiceFilter):
@@ -385,12 +406,16 @@ class QuerySetRequestMixin(object):
         return super(QuerySetRequestMixin, self).field
 
 
-class ModelChoiceFilter(QuerySetRequestMixin, Filter):
-    field_class = forms.ModelChoiceField
+class ModelChoiceFilter(QuerySetRequestMixin, ChoiceFilter):
+    field_class = ModelChoiceField
+
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('empty_label', settings.EMPTY_CHOICE_LABEL)
+        super(ModelChoiceFilter, self).__init__(*args, **kwargs)
 
 
 class ModelMultipleChoiceFilter(QuerySetRequestMixin, MultipleChoiceFilter):
-    field_class = forms.ModelMultipleChoiceField
+    field_class = ModelMultipleChoiceField
 
 
 class NumberFilter(Filter):
@@ -403,13 +428,13 @@ class NumericRangeFilter(Filter):
     def filter(self, qs, value):
         if value:
             if value.start is not None and value.stop is not None:
-                lookup = '%s__%s' % (self.name, self.lookup_expr)
+                lookup = '%s__%s' % (self.field_name, self.lookup_expr)
                 return self.get_method(qs)(**{lookup: (value.start, value.stop)})
             else:
                 if value.start is not None:
-                    qs = self.get_method(qs)(**{'%s__startswith' % self.name: value.start})
+                    qs = self.get_method(qs)(**{'%s__startswith' % self.field_name: value.start})
                 if value.stop is not None:
-                    qs = self.get_method(qs)(**{'%s__endswith' % self.name: value.stop})
+                    qs = self.get_method(qs)(**{'%s__endswith' % self.field_name: value.stop})
             if self.distinct:
                 qs = qs.distinct()
         return qs
@@ -421,13 +446,13 @@ class RangeFilter(Filter):
     def filter(self, qs, value):
         if value:
             if value.start is not None and value.stop is not None:
-                lookup = '%s__range' % self.name
+                lookup = '%s__range' % self.field_name
                 return self.get_method(qs)(**{lookup: (value.start, value.stop)})
             else:
                 if value.start is not None:
-                    qs = self.get_method(qs)(**{'%s__gte' % self.name: value.start})
+                    qs = self.get_method(qs)(**{'%s__gte' % self.field_name: value.start})
                 if value.stop is not None:
-                    qs = self.get_method(qs)(**{'%s__lte' % self.name: value.stop})
+                    qs = self.get_method(qs)(**{'%s__lte' % self.field_name: value.stop})
             if self.distinct:
                 qs = qs.distinct()
         return qs
@@ -479,7 +504,7 @@ class DateRangeFilter(ChoiceFilter):
             value = ''
 
         assert value in self.options
-        qs = self.options[value][1](qs, self.name)
+        qs = self.options[value][1](qs, self.field_name)
         if self.distinct:
             qs = qs.distinct()
         return qs
@@ -501,7 +526,7 @@ class AllValuesFilter(ChoiceFilter):
     @property
     def field(self):
         qs = self.model._default_manager.distinct()
-        qs = qs.order_by(self.name).values_list(self.name, flat=True)
+        qs = qs.order_by(self.field_name).values_list(self.field_name, flat=True)
         self.extra['choices'] = [(o, o) for o in qs]
         return super(AllValuesFilter, self).field
 
@@ -510,7 +535,7 @@ class AllValuesMultipleFilter(MultipleChoiceFilter):
     @property
     def field(self):
         qs = self.model._default_manager.distinct()
-        qs = qs.order_by(self.name).values_list(self.name, flat=True)
+        qs = qs.order_by(self.field_name).values_list(self.field_name, flat=True)
         self.extra['choices'] = [(o, o) for o in qs]
         return super(AllValuesMultipleFilter, self).field
 
@@ -618,6 +643,7 @@ class OrderingFilter(BaseCSVFilter, ChoiceFilter):
             kwargs['choices'] = self.build_choices(fields, field_labels)
 
         kwargs.setdefault('label', _('Ordering'))
+        kwargs.setdefault('help_text', '')
         kwargs.setdefault('null_label', None)
         super(OrderingFilter, self).__init__(*args, **kwargs)
 
@@ -684,7 +710,7 @@ class FilterMethod(object):
         if value in EMPTY_VALUES:
             return qs
 
-        return self.method(qs, self.f.name, value)
+        return self.method(qs, self.f.field_name, value)
 
     @property
     def method(self):
@@ -700,7 +726,7 @@ class FilterMethod(object):
         # otherwise, method is the name of a method on the parent FilterSet.
         assert hasattr(instance, 'parent'), \
             "Filter '%s' must have a parent FilterSet to find '.%s()'" %  \
-            (instance.name, instance.method)
+            (instance.field_name, instance.method)
 
         parent = instance.parent
         method = getattr(parent, instance.method, None)
