@@ -1,20 +1,22 @@
 from __future__ import unicode_literals
 
 import datetime
+import warnings
 from decimal import Decimal
 from unittest import skipIf
-import warnings
 
 from django.db.models import BooleanField
 from django.test import TestCase
 from django.test.utils import override_settings
-
 from rest_framework import generics, serializers
 from rest_framework.test import APIRequestFactory
 
 from django_filters import compat, filters
-from django_filters.rest_framework import DjangoFilterBackend, FilterSet
-from django_filters.rest_framework import backends
+from django_filters.rest_framework import (
+    DjangoFilterBackend,
+    FilterSet,
+    backends
+)
 
 from .models import FilterableItem
 
@@ -106,6 +108,27 @@ class GetSchemaFieldsTests(TestCase):
         self.assertIsInstance(schemas[1], compat.coreschema.Number)
         self.assertIsInstance(schemas[2], compat.coreschema.String)
 
+    def test_field_required(self):
+        class RequiredFieldsFilter(SeveralFieldsFilter):
+            required_text = filters.CharFilter(required=True)
+
+            class Meta(SeveralFieldsFilter.Meta):
+                fields = SeveralFieldsFilter.Meta.fields + ['required_text']
+
+        class FilterClassWithRequiredFieldsView(FilterClassRootView):
+            filter_class = RequiredFieldsFilter
+
+        backend = DjangoFilterBackend()
+        fields = backend.get_schema_fields(FilterClassWithRequiredFieldsView())
+        required = [f.required for f in fields]
+        fields = [f.name for f in fields]
+
+        self.assertEqual(fields, ['text', 'decimal', 'date', 'required_text'])
+        self.assertFalse(required[0])
+        self.assertFalse(required[1])
+        self.assertFalse(required[2])
+        self.assertTrue(required[3])
+
     def tests_field_with_request_callable(self):
         def qs(request):
             # users expect a valid request object to be provided which cannot
