@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 import datetime
 import mock
@@ -8,42 +7,45 @@ import unittest
 import django
 from django import forms
 from django.test import TestCase, override_settings
-from django.utils import six
+from django.utils import six, timezone
 from django.utils.timezone import now
-from django.utils import timezone
 
-from django_filters.filterset import FilterSet
-from django_filters.filters import AllValuesFilter
-from django_filters.filters import AllValuesMultipleFilter
-from django_filters.filters import CharFilter
-from django_filters.filters import ChoiceFilter
-from django_filters.filters import DateRangeFilter
-from django_filters.filters import DateFromToRangeFilter
-from django_filters.filters import DateTimeFromToRangeFilter
-from django_filters.filters import DurationFilter
-from django_filters.filters import MultipleChoiceFilter
-from django_filters.filters import ModelChoiceFilter
-from django_filters.filters import TypedMultipleChoiceFilter
-from django_filters.filters import ModelMultipleChoiceFilter
-from django_filters.filters import NumberFilter
-from django_filters.filters import OrderingFilter
-from django_filters.filters import RangeFilter
-from django_filters.filters import TimeRangeFilter
 from django_filters.exceptions import FieldLookupError
+from django_filters.filters import (
+    AllValuesFilter,
+    AllValuesMultipleFilter,
+    CharFilter,
+    ChoiceFilter,
+    DateFromToRangeFilter,
+    DateRangeFilter,
+    DateTimeFromToRangeFilter,
+    DurationFilter,
+    ModelChoiceFilter,
+    ModelMultipleChoiceFilter,
+    MultipleChoiceFilter,
+    NumberFilter,
+    OrderingFilter,
+    RangeFilter,
+    TimeRangeFilter,
+    TypedMultipleChoiceFilter
+)
+from django_filters.filterset import FilterSet
 
-from .models import User
-from .models import Comment
-from .models import Book
-from .models import Article
-from .models import Company
-from .models import Location
-from .models import Account
-from .models import BankAccount
-from .models import Profile
-from .models import Node
-from .models import DirectedNode
-from .models import STATUS_CHOICES
-from .models import SpacewalkRecord
+from .models import (
+    STATUS_CHOICES,
+    Account,
+    Article,
+    BankAccount,
+    Book,
+    Comment,
+    Company,
+    DirectedNode,
+    Location,
+    Node,
+    Profile,
+    SpacewalkRecord,
+    User
+)
 
 
 class CharFilterTests(TestCase):
@@ -252,6 +254,44 @@ class MultipleChoiceFilterTests(TestCase):
         self.assertQuerysetEqual(
             f.qs, ['aaron', 'alex', 'carl', 'jacob'], lambda o: o.username)
 
+    def test_filtering_on_null_choice(self):
+        User.objects.create(username='alex', status=1)
+        User.objects.create(username='jacob', status=2)
+        User.objects.create(username='aaron', status=2)
+        User.objects.create(username='carl', status=0)
+
+        Article.objects.create(author_id=1, published=now())
+        Article.objects.create(author_id=2, published=now())
+        Article.objects.create(author_id=3, published=now())
+        Article.objects.create(author_id=4, published=now())
+        Article.objects.create(author_id=None, published=now())
+
+        choices = [(u.pk, str(u)) for u in User.objects.order_by('id')]
+
+        class F(FilterSet):
+            author = MultipleChoiceFilter(
+                choices=choices,
+                null_value='null',
+                null_label='NULL',
+            )
+
+            class Meta:
+                model = Article
+                fields = ['author']
+
+        # sanity check to make sure the filter is setup correctly
+        f = F({'author': ['1']})
+        self.assertQuerysetEqual(f.qs, ['alex'], lambda o: str(o.author), False)
+
+        f = F({'author': ['null']})
+        self.assertQuerysetEqual(f.qs, [None], lambda o: o.author, False)
+
+        f = F({'author': ['1', 'null']})
+        self.assertQuerysetEqual(
+            f.qs, ['alex', None],
+            lambda o: o.author and str(o.author),
+            False)
+
 
 class TypedMultipleChoiceFilterTests(TestCase):
 
@@ -485,6 +525,21 @@ class ModelChoiceFilterTests(TestCase):
         f = F({'author': jacob.pk}, queryset=qs)
         self.assertQuerysetEqual(f.qs, [1, 3], lambda o: o.pk, False)
 
+    @override_settings(FILTERS_NULL_CHOICE_LABEL='No Author')
+    def test_filtering_null(self):
+        Article.objects.create(published=now())
+        alex = User.objects.create(username='alex')
+        Article.objects.create(author=alex, published=now())
+
+        class F(FilterSet):
+            class Meta:
+                model = Article
+                fields = ['author', 'name']
+
+        qs = Article.objects.all()
+        f = F({'author': 'null'}, queryset=qs)
+        self.assertQuerysetEqual(f.qs, [None], lambda o: o.author, False)
+
     def test_callable_queryset(self):
         # Sanity check for callable queryset arguments.
         # Ensure that nothing is improperly cached
@@ -552,6 +607,18 @@ class ModelMultipleChoiceFilterTests(TestCase):
         f = F({'favorite_books': ['4']}, queryset=qs)
         self.assertQuerysetEqual(f.qs, [], lambda o: o.username)
 
+    @override_settings(FILTERS_NULL_CHOICE_LABEL='No Favorites')
+    def test_filtering_null(self):
+        class F(FilterSet):
+            class Meta:
+                model = User
+                fields = ['favorite_books']
+
+        qs = User.objects.all()
+        f = F({'favorite_books': ['null']}, queryset=qs)
+
+        self.assertQuerysetEqual(f.qs, ['jacob'], lambda o: o.username)
+
     def test_filtering_dictionary(self):
         class F(FilterSet):
             class Meta:
@@ -584,7 +651,7 @@ class ModelMultipleChoiceFilterTests(TestCase):
                     'queryset': Book.objects.filter(id__in=[1, 2])
                 })
 
-                self.filters['favorite_books'].required = True
+                self.filters['favorite_books'].extra['required'] = True
 
         qs = User.objects.all().order_by('username')
 
