@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
-from collections import OrderedDict
-from datetime import date, time, timedelta, datetime
 import inspect
 import mock
+from collections import OrderedDict
+from datetime import date, datetime, time, timedelta
 
 from django import forms
 from django.test import TestCase, override_settings
@@ -14,41 +13,42 @@ from django.utils.translation import ugettext as _
 
 from django_filters import filters, widgets
 from django_filters.fields import (
-    Lookup,
-    RangeField,
+    BaseCSVField,
     DateRangeField,
     DateTimeRangeField,
-    TimeRangeField,
+    Lookup,
     LookupTypeField,
-    BaseCSVField)
+    RangeField,
+    TimeRangeField
+)
 from django_filters.filters import (
-    Filter,
-    CharFilter,
-    BooleanFilter,
-    ChoiceFilter,
-    MultipleChoiceFilter,
-    TypedMultipleChoiceFilter,
-    DateFilter,
-    DateTimeFilter,
-    TimeFilter,
-    DurationFilter,
-    ModelChoiceFilter,
-    ModelMultipleChoiceFilter,
-    NumberFilter,
-    NumericRangeFilter,
-    RangeFilter,
-    DateRangeFilter,
-    DateFromToRangeFilter,
-    DateTimeFromToRangeFilter,
-    TimeRangeFilter,
+    LOOKUP_TYPES,
     AllValuesFilter,
     BaseCSVFilter,
     BaseInFilter,
     BaseRangeFilter,
-    UUIDFilter,
+    BooleanFilter,
+    CharFilter,
+    ChoiceFilter,
+    DateFilter,
+    DateFromToRangeFilter,
+    DateRangeFilter,
+    DateTimeFilter,
+    DateTimeFromToRangeFilter,
+    DurationFilter,
+    Filter,
+    ModelChoiceFilter,
+    ModelMultipleChoiceFilter,
+    MultipleChoiceFilter,
+    NumberFilter,
+    NumericRangeFilter,
     OrderingFilter,
-    LOOKUP_TYPES)
-
+    RangeFilter,
+    TimeFilter,
+    TimeRangeFilter,
+    TypedMultipleChoiceFilter,
+    UUIDFilter
+)
 from tests.models import Book, User
 
 
@@ -132,17 +132,16 @@ class FilterTests(TestCase):
             f.field
             mocked.assert_called_once_with(required=mock.ANY,
                                            label=mock.ANY,
-                                           widget=mock.ANY,
                                            someattr='someattr')
 
-    def test_field_with_required_filter(self):
+    def test_field_required_default(self):
+        # filter form fields should not be required by default
         with mock.patch.object(Filter, 'field_class',
                                spec=['__call__']) as mocked:
-            f = Filter(required=True)
+            f = Filter()
             f.field
-            mocked.assert_called_once_with(required=True,
-                                           label=mock.ANY,
-                                           widget=mock.ANY)
+            mocked.assert_called_once_with(required=False,
+                                           label=mock.ANY)
 
     def test_filtering(self):
         qs = mock.Mock(spec=['filter'])
@@ -313,35 +312,35 @@ class ChoiceFilterTests(TestCase):
     def test_empty_choice(self):
         # default value
         f = ChoiceFilter(choices=[('a', 'a')])
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('a', 'a'),
         ])
 
         # set value, allow blank label
         f = ChoiceFilter(choices=[('a', 'a')], empty_label='')
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', ''),
             ('a', 'a'),
         ])
 
         # disable empty choice w/ None
         f = ChoiceFilter(choices=[('a', 'a')], empty_label=None)
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('a', 'a'),
         ])
 
     def test_null_choice(self):
         # default is to be disabled
         f = ChoiceFilter(choices=[('a', 'a')], )
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('a', 'a'),
         ])
 
         # set label, allow blank label
         f = ChoiceFilter(choices=[('a', 'a')], null_label='')
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('null', ''),
             ('a', 'a'),
@@ -349,7 +348,7 @@ class ChoiceFilterTests(TestCase):
 
         # set null value
         f = ChoiceFilter(choices=[('a', 'a')], null_value='NULL', null_label='')
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('NULL', ''),
             ('a', 'a'),
@@ -357,35 +356,73 @@ class ChoiceFilterTests(TestCase):
 
         # explicitly disable
         f = ChoiceFilter(choices=[('a', 'a')], null_label=None)
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('a', 'a'),
         ])
 
+    def test_null_multiplechoice(self):
+        # default is to be disabled
+        f = MultipleChoiceFilter(choices=[('a', 'a')], )
+        self.assertEqual(list(f.field.choices), [
+            ('a', 'a'),
+        ])
+
+        # set label, allow blank label
+        f = MultipleChoiceFilter(choices=[('a', 'a')], null_label='')
+        self.assertEqual(list(f.field.choices), [
+            ('null', ''),
+            ('a', 'a'),
+        ])
+
+        # set null value
+        f = MultipleChoiceFilter(choices=[('a', 'a')], null_value='NULL', null_label='')
+        self.assertEqual(list(f.field.choices), [
+            ('NULL', ''),
+            ('a', 'a'),
+        ])
+
+        # explicitly disable
+        f = MultipleChoiceFilter(choices=[('a', 'a')], null_label=None)
+        self.assertEqual(list(f.field.choices), [
+            ('a', 'a'),
+        ])
+
     @override_settings(
         FILTERS_EMPTY_CHOICE_LABEL='EMPTY LABEL',
         FILTERS_NULL_CHOICE_LABEL='NULL LABEL',
         FILTERS_NULL_CHOICE_VALUE='NULL VALUE', )
     def test_settings_overrides(self):
         f = ChoiceFilter(choices=[('a', 'a')], )
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', 'EMPTY LABEL'),
             ('NULL VALUE', 'NULL LABEL'),
             ('a', 'a'),
         ])
 
+        f = MultipleChoiceFilter(choices=[('a', 'a')], )
+        self.assertEqual(list(f.field.choices), [
+            ('NULL VALUE', 'NULL LABEL'),
+            ('a', 'a'),
+        ])
+
     def test_callable_choices(self):
         def choices():
             yield ('a', 'a')
             yield ('b', 'b')
 
         f = ChoiceFilter(choices=choices)
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('a', 'a'),
             ('b', 'b'),
         ])
 
+    def test_callable_choices_is_lazy(self):
+        def choices():
+            self.fail('choices should not be called during initialization')
+        ChoiceFilter(choices=choices)
+
 
 class MultipleChoiceFilterTests(TestCase):
 
@@ -700,6 +737,16 @@ class ModelChoiceFilterTests(TestCase):
         with self.assertRaises(TypeError):
             f.field
 
+    @override_settings(
+        FILTERS_EMPTY_CHOICE_LABEL='EMPTY',
+        FILTERS_NULL_CHOICE_VALUE='NULL', )
+    def test_empty_choices(self):
+        f = ModelChoiceFilter(queryset=User.objects.all(), null_value='null', null_label='NULL')
+        self.assertEqual(list(f.field.choices), [
+            ('', 'EMPTY'),
+            ('null', 'NULL'),
+        ])
+
     def test_default_field_with_queryset(self):
         qs = mock.NonCallableMock(spec=[])
         f = ModelChoiceFilter(queryset=qs)
@@ -742,6 +789,15 @@ class ModelMultipleChoiceFilterTests(TestCase):
         with self.assertRaises(TypeError):
             f.field
 
+    @override_settings(
+        FILTERS_EMPTY_CHOICE_LABEL='EMPTY',
+        FILTERS_NULL_CHOICE_VALUE='NULL', )
+    def test_empty_choices(self):
+        f = ModelMultipleChoiceFilter(queryset=User.objects.all(), null_value='null', null_label='NULL')
+        self.assertEqual(list(f.field.choices), [
+            ('null', 'NULL'),
+        ])
+
     def test_default_field_with_queryset(self):
         qs = mock.NonCallableMock(spec=[])
         f = ModelMultipleChoiceFilter(queryset=qs)
@@ -1146,6 +1202,14 @@ class AllValuesFilterTests(TestCase):
         field = f.field
         self.assertIsInstance(field, forms.ChoiceField)
 
+    def test_empty_value_in_choices(self):
+        f = AllValuesFilter(name='username')
+        f.model = User
+
+        self.assertEqual(list(f.field.choices), [
+            ('', '---------'),
+        ])
+
 
 class LookupTypesTests(TestCase):
     def test_custom_lookup_exprs(self):
@@ -1296,7 +1360,7 @@ class OrderingFilterTests(TestCase):
             fields=(('a', 'c'), ('b', 'd')),
         )
 
-        self.assertSequenceEqual(f.field.choices, (
+        self.assertSequenceEqual(list(f.field.choices), (
             ('', '---------'),
             ('a', 'A'),
             ('b', 'B'),
@@ -1307,7 +1371,7 @@ class OrderingFilterTests(TestCase):
             fields=(('a', 'c'), ('b', 'd')),
         )
 
-        self.assertSequenceEqual(f.field.choices, (
+        self.assertSequenceEqual(list(f.field.choices), (
             ('', '---------'),
             ('c', 'C'),
             ('-c', 'C (descending)'),
@@ -1321,7 +1385,7 @@ class OrderingFilterTests(TestCase):
             field_labels={'a': 'foo'},
         )
 
-        self.assertSequenceEqual(f.field.choices, (
+        self.assertSequenceEqual(list(f.field.choices), (
             ('', '---------'),
             ('c', 'foo'),
             ('-c', 'foo (descending)'),
@@ -1338,7 +1402,7 @@ class OrderingFilterTests(TestCase):
             }
         )
 
-        self.assertEqual(f.field.choices, [
+        self.assertEqual(list(f.field.choices), [
             ('', '---------'),
             ('username', 'BLABLA'),
             ('-username', 'XYZXYZ'),
@@ -1393,7 +1457,7 @@ class OrderingFilterTests(TestCase):
         with translation.override('pl'):
             f = OrderingFilter(fields=['username'])
 
-            self.assertEqual(f.field.choices, [
+            self.assertEqual(list(f.field.choices), [
                 ('', '---------'),
                 ('username', 'Nazwa użytkownika'),
                 ('-username', 'Nazwa użytkownika (malejąco)'),
@@ -1406,8 +1470,13 @@ class OrderingFilterTests(TestCase):
                 field_labels={'username': 'BLABLA'},
             )
 
-            self.assertEqual(f.field.choices, [
+            self.assertEqual(list(f.field.choices), [
                 ('', '---------'),
                 ('username', 'BLABLA'),
                 ('-username', 'BLABLA (malejąco)'),
             ])
+
+    def test_help_text(self):
+        # regression test for #756 - the ususal CSV help_text is not relevant to ordering filters.
+        self.assertEqual(OrderingFilter().field.help_text, '')
+        self.assertEqual(OrderingFilter(help_text='a').field.help_text, 'a')
