@@ -1,15 +1,18 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
+from django.forms import Select, TextInput
 from django.test import TestCase
-from django.forms import TextInput, Select
 
-from django_filters.widgets import BooleanWidget, QueryArrayWidget
-from django_filters.widgets import BaseCSVWidget
-from django_filters.widgets import CSVWidget
-from django_filters.widgets import RangeWidget
-from django_filters.widgets import LinkWidget
-from django_filters.widgets import LookupTypeWidget
+from django_filters.widgets import (
+    BaseCSVWidget,
+    BooleanWidget,
+    CSVWidget,
+    LinkWidget,
+    LookupTypeWidget,
+    QueryArrayWidget,
+    RangeWidget,
+    SuffixedMultiWidget
+)
 
 
 class LookupTypeWidgetTests(TestCase):
@@ -121,6 +124,70 @@ class LinkWidgetTests(TestCase):
         self.assertEqual(result, 'test-val1')
 
 
+class SuffixedMultiWidgetTests(TestCase):
+    def test_assertions(self):
+        # number of widgets must match suffixes
+        with self.assertRaises(AssertionError):
+            SuffixedMultiWidget(widgets=[BooleanWidget])
+
+        # suffixes must be unique
+        class W(SuffixedMultiWidget):
+            suffixes = ['a', 'a']
+
+        with self.assertRaises(AssertionError):
+            W(widgets=[BooleanWidget, BooleanWidget])
+
+        # should succeed
+        class W(SuffixedMultiWidget):
+            suffixes = ['a', 'b']
+        W(widgets=[BooleanWidget, BooleanWidget])
+
+    def test_render(self):
+        class W(SuffixedMultiWidget):
+            suffixes = ['min', 'max']
+
+        w = W(widgets=[TextInput, TextInput])
+        self.assertHTMLEqual(w.render('price', ''), """
+            <input name="price_min" type="text" />
+            <input name="price_max" type="text" />
+        """)
+
+        # blank suffix
+        class W(SuffixedMultiWidget):
+            suffixes = [None, 'lookup']
+
+        w = W(widgets=[TextInput, TextInput])
+        self.assertHTMLEqual(w.render('price', ''), """
+            <input name="price" type="text" />
+            <input name="price_lookup" type="text" />
+        """)
+
+    def test_value_from_datadict(self):
+        class W(SuffixedMultiWidget):
+            suffixes = ['min', 'max']
+
+        w = W(widgets=[TextInput, TextInput])
+        result = w.value_from_datadict({
+            'price_min': '1',
+            'price_max': '2',
+        }, {}, 'price')
+        self.assertEqual(result, ['1', '2'])
+
+        result = w.value_from_datadict({}, {}, 'price')
+        self.assertEqual(result, [None, None])
+
+        # blank suffix
+        class W(SuffixedMultiWidget):
+            suffixes = ['', 'lookup']
+
+        w = W(widgets=[TextInput, TextInput])
+        result = w.value_from_datadict({
+            'price': '1',
+            'price_lookup': 'lt',
+        }, {}, 'price')
+        self.assertEqual(result, ['1', 'lt'])
+
+
 class RangeWidgetTests(TestCase):
 
     def test_widget(self):
