@@ -1,11 +1,12 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 from django.conf.urls import url
 
 from django_filters.views import FilterView, object_filter
+
 from .models import Book
 
+
 def _foo():
     return 'bar'
 
